'' =================================================================================================
''
''   File....... jm_sht11_demo.spin
''   Purpose.... Simple demo of jm_sht11.spin objects
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (C) 2015 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started....
''   Updated.... 18 OCT 2015
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us


con { io pins }

  RX1 = 31                                                       ' programming / terminal
  TX1 = 30

  SDA = 29                                                       ' i2c / eeprom
  SCL = 28

  DIO = 15
  SCK = 14


obj

' main                                                           ' * master Spin cog
  time : "jm_time"                                               '   timing and delays
  io   : "jm_io_basic"                                           '   essential io control
  sht  : "jm_sht11"                                              '   SHT11 sensor interface
  term : "jm_fullduplexserial"                                   ' * serial io for terminal

' * Uses cog when loaded


var


pub main | t

  setup

  time.pause(2000)                                               ' time to open terminal
  term.tx(term#CLS)

  if (sht.soft_reset == sht#ACK)
    term.str(string("Connected"))
  else
    term.str(string("Fail to connect"))
    repeat
      waitcnt(0)

  repeat 2
    term.tx(13)

  t := cnt
  repeat
    waitcnt(cnt + clkfreq)                                       ' 1s between readings
    show_temperature
    show_humidity
    term.tx(term#CR)


pub show_temperature | tmp

  sht.temperature                                                ' read temperature

  tmp := (sht.temp_c + 5) / 10                                   ' round up to 10ths   
  term.dec(tmp/10)                                               ' display whole degrees              
  term.tx(".")                   
  term.dec(tmp//10)                                              ' display tenth degrees
  term.tx("C")               
  term.tx(term#TAB)

  tmp := (sht.temp_f + 5) / 10                              
  term.dec(tmp/10)                
  term.tx(".")                   
  term.dec(tmp//10)
  term.tx("F")              
  term.tx(term#TAB)                


pub show_humidity | rh

  sht.humidity                                                   ' read humidity

  rh := (sht.rh_linear + 5) / 10                           
  term.dec(rh/10)                
  term.tx(".")                   
  term.dec(rh//10)
  term.tx("%")               
  term.tx(term#TAB)

  rh := (sht.rh_true + 5) / 10    
  term.dec(rh/10)                
  term.tx(".")                   
  term.dec(rh//10)               
  term.tx("%")               
  term.tx(term#TAB)   


pub setup

'' Setup IO and objects for application

  time.start                                                     ' setup timing/delays for clock speed

  io.start(0, 0)                                                 ' clear all pins

  sht.start(SCK, DIO)                                            ' connect to SHT11 module

  term.start(RX1, TX1, %0000, 115_200)                           ' start serial for terminal


dat { license }

{{

  Copyright (C) 2015 Jon McPhalen

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}